@@ -44,6 +44,9 @@ $action = required_param('action', PARAM_ALPHA);
 $factory = new factory();
 $editor = $factory->get_editor();
 
+// Set context to default system context.
+$PAGE->set_context(null);
+
 switch ($action) {
     // Load list of libraries or details for library.
     case 'libraries':
@@ -52,7 +55,9 @@ switch ($action) {
         $major = optional_param('majorVersion', 0, PARAM_INT);
         $minor = optional_param('minorVersion', 0, PARAM_INT);
 
-        $language = optional_param('default-language', null, PARAM_ALPHA);
+        // Normalise Moodle language using underscore, as opposed to H5P which uses dash.
+        $language = optional_param('default-language', null, PARAM_RAW);
+        $language = clean_param(str_replace('-', '_', $language), PARAM_LANG);
 
         if (!empty($name)) {
             $editor->ajax->action(H5PEditorEndpoints::SINGLE_LIBRARY, $name,
@@ -75,6 +80,17 @@ switch ($action) {
         $token = required_param('token', PARAM_RAW);
         $contentid = required_param('contentId', PARAM_INT);
 
+        $maxsize = get_max_upload_file_size($CFG->maxbytes);
+        // Check size of each uploaded file and scan for viruses.
+        foreach ($_FILES as $uploadedfile) {
+            $filename = clean_param($uploadedfile['name'], PARAM_FILE);
+            if ($uploadedfile['size'] > $maxsize) {
+                H5PCore::ajaxError(get_string('maxbytesfile', 'error', ['file' => $filename, 'size' => display_size($maxsize)]));
+                return;
+            }
+            \core\antivirus\manager::scan_file($uploadedfile['tmp_name'], $filename, true);
+        }
+
         $editor->ajax->action(H5PEditorEndpoints::FILES, $token, $contentid);
         break;
 
