@@ -54,18 +54,29 @@
 // You should have received a copy of the GNU General Public License
 // along with Moodle. If not, see <http://www.gnu.org/licenses/>.
 
+/**
+ * This file contains the OAuth 1.0a implementation used for support for LTI 1.1.
+ *
+ * @package    mod_lti
+ * @copyright moodle
+ * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ */
 namespace moodle\mod\lti;//Using a namespace as the basicLTI module imports classes with the same names
 
 defined('MOODLE_INTERNAL') || die;
 
-$oauth_last_computed_signature = false;
+$lastcomputedsignature = false;
 
-/* Generic exception class
+/**
+ * Generic exception class
  */
 class OAuthException extends \Exception {
     // pass
 }
 
+/**
+ * OAuth 1.0 Consumer class
+ */
 class OAuthConsumer {
     public $key;
     public $secret;
@@ -118,17 +129,25 @@ class OAuthSignatureMethod {
     }
 }
 
-class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod {
-    function get_name() {
-        return "HMAC-SHA1";
-    }
+
+/**
+ * Base class for the HMac based signature methods.
+ */
+abstract class OAuthSignatureMethod_HMAC extends OAuthSignatureMethod {
+
+    /**
+     * Name of the Algorithm used.
+     *
+     * @return string algorithm name.
+     */
+    abstract public function get_name(): string;
 
     public function build_signature($request, $consumer, $token) {
-        global $oauth_last_computed_signature;
-        $oauth_last_computed_signature = false;
+        global $lastcomputedsignature;
+        $lastcomputedsignature = false;
 
-        $base_string = $request->get_signature_base_string();
-        $request->base_string = $base_string;
+        $basestring = $request->get_signature_base_string();
+        $request->base_string = $basestring;
 
         $key_parts = array(
             $consumer->secret,
@@ -138,15 +157,48 @@ class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod {
         $key_parts = OAuthUtil::urlencode_rfc3986($key_parts);
         $key = implode('&', $key_parts);
 
-        $computed_signature = base64_encode(hash_hmac('sha1', $base_string, $key, true));
-        $oauth_last_computed_signature = $computed_signature;
-        return $computed_signature;
+        $computedsignature = base64_encode(hash_hmac(strtolower(substr($this->get_name(), 5)), $basestring, $key, true));
+        $lastcomputedsignature = $computedsignature;
+        return $computedsignature;
     }
 
 }
 
+/**
+ * Implementation for SHA 1.
+ */
+class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod_HMAC {
+    /**
+     * Name of the Algorithm used.
+     *
+     * @return string algorithm name.
+     */
+    public function get_name(): string {
+        return "HMAC-SHA1";
+    }
+}
+
+/**
+ * Implementation for SHA 256.
+ */
+class OAuthSignatureMethod_HMAC_SHA256 extends OAuthSignatureMethod_HMAC {
+    /**
+     * Name of the Algorithm used.
+     *
+     * @return string algorithm name.
+     */
+    public function get_name(): string {
+        return "HMAC-SHA256";
+    }
+}
+
 class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod {
-    public function get_name() {
+    /**
+     * Name of the Algorithm used.
+     *
+     * @return string algorithm name.
+     */
+    public function get_name(): string {
         return "PLAINTEXT";
     }
 
@@ -170,7 +222,12 @@ class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod {
 }
 
 class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
-    public function get_name() {
+    /**
+     * Name of the Algorithm used.
+     *
+     * @return string algorithm name.
+     */
+    public function get_name(): string {
         return "RSA-SHA1";
     }
 
@@ -181,7 +238,7 @@ class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
         // (3) some sort of specific discovery code based on request
         //
         // either way should return a string representation of the certificate
-        throw OAuthException("fetch_public_cert not implemented");
+        throw new OAuthException("fetch_public_cert not implemented");
     }
 
     protected function fetch_private_cert(&$request) {
@@ -189,7 +246,7 @@ class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
         // (1) do a lookup in a table of trusted certs keyed off of consumer
         //
         // either way should return a string representation of the certificate
-        throw OAuthException("fetch_private_cert not implemented");
+        throw new OAuthException("fetch_private_cert not implemented");
     }
 
     public function build_signature(&$request, $consumer, $token) {
@@ -252,7 +309,7 @@ class OAuthRequest {
      * attempt to build up a request from what was passed to the server
      */
     public static function from_request($http_method = null, $http_url = null, $parameters = null) {
-        $scheme = (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != "on") ? 'http' : 'https';
+        $scheme = (!is_https()) ? 'http' : 'https';
         $port = "";
         if ($_SERVER['SERVER_PORT'] != "80" && $_SERVER['SERVER_PORT'] != "443" && strpos(':', $_SERVER['HTTP_HOST']) < 0) {
             $port = ':' . $_SERVER['SERVER_PORT'];
@@ -275,15 +332,6 @@ class OAuthRequest {
             $parameters = OAuthUtil::parse_parameters($_SERVER['QUERY_STRING']);
 
             $ourpost = $_POST;
-            // Deal with magic_quotes
-            // http://www.php.net/manual/en/security.magicquotes.disabling.php
-            if (get_magic_quotes_gpc()) {
-                $outpost = array();
-                foreach ($_POST as $k => $v) {
-                    $v = stripslashes($v);
-                    $ourpost[$k] = $v;
-                }
-            }
             // Add POST Parameters if they exist
             $parameters = array_merge($parameters, $ourpost);
 
@@ -548,8 +596,8 @@ class OAuthServer {
      * verify an api call, checks all the parameters
      */
     public function verify_request(&$request) {
-        global $oauth_last_computed_signature;
-        $oauth_last_computed_signature = false;
+        global $lastcomputedsignature;
+        $lastcomputedsignature = false;
         $this->get_version($request);
         $consumer = $this->get_consumer($request);
         $token = $this->get_token($request, $consumer, "access");
@@ -629,8 +677,8 @@ class OAuthServer {
      */
     private function check_signature(&$request, $consumer, $token) {
         // this should probably be in a different method
-        global $oauth_last_computed_signature;
-        $oauth_last_computed_signature = false;
+        global $lastcomputedsignature;
+        $lastcomputedsignature = false;
 
         $timestamp = @ $request->get_parameter('oauth_timestamp');
         $nonce = @ $request->get_parameter('oauth_nonce');
@@ -645,8 +693,8 @@ class OAuthServer {
 
         if (!$valid_sig) {
             $ex_text = "Invalid signature";
-            if ($oauth_last_computed_signature) {
-                $ex_text = $ex_text . " ours= $oauth_last_computed_signature yours=$signature";
+            if ($lastcomputedsignature) {
+                $ex_text = $ex_text . " ours= $lastcomputedsignature yours=$signature";
             }
             throw new OAuthException($ex_text);
         }
@@ -754,7 +802,13 @@ class OAuthUtil {
         if (function_exists('apache_request_headers')) {
             // we need this to get the actual Authorization: header
             // because apache tends to tell us it doesn't exist
-            return apache_request_headers();
+            $in = apache_request_headers();
+            $out = array();
+            foreach ($in as $key => $value) {
+                $key = str_replace(" ", "-", ucwords(strtolower(str_replace("-", " ", $key))));
+                $out[$key] = $value;
+            }
+            return $out;
         }
         // otherwise we don't have apache and are just going to have to hope
         // that $_SERVER actually contains what we need
