@@ -252,10 +252,11 @@ function resource_get_coursemodule_info($coursemodule) {
     if (($filedetails = resource_get_file_details($resource, $coursemodule)) && empty($filedetails['isref'])) {
         $displayoptions = @unserialize($resource->displayoptions);
         $displayoptions['filedetails'] = $filedetails;
-        $info->customdata = serialize($displayoptions);
+        $info->customdata['displayoptions'] = serialize($displayoptions);
     } else {
-        $info->customdata = $resource->displayoptions;
+        $info->customdata['displayoptions'] = $resource->displayoptions;
     }
+    $info->customdata['display'] = $display;
 
     return $info;
 }
@@ -270,7 +271,7 @@ function resource_cm_info_view(cm_info $cm) {
     global $CFG;
     require_once($CFG->dirroot . '/mod/resource/locallib.php');
 
-    $resource = (object)array('displayoptions' => $cm->customdata);
+    $resource = (object) ['displayoptions' => $cm->customdata['displayoptions']];
     $details = resource_get_optional_details($resource, $cm);
     if ($details) {
         $cm->set_after_link(' ' . html_writer::tag('span', $details,
@@ -584,3 +585,28 @@ function mod_resource_core_calendar_provide_event_action(calendar_event $event,
         true
     );
 }
+
+
+/**
+ * Given an array with a file path, it returns the itemid and the filepath for the defined filearea.
+ *
+ * @param  string $filearea The filearea.
+ * @param  array  $args The path (the part after the filearea and before the filename).
+ * @return array The itemid and the filepath inside the $args path, for the defined filearea.
+ */
+function mod_resource_get_path_from_pluginfile(string $filearea, array $args) : array {
+    // Resource never has an itemid (the number represents the revision but it's not stored in database).
+    array_shift($args);
+
+    // Get the filepath.
+    if (empty($args)) {
+        $filepath = '/';
+    } else {
+        $filepath = '/' . implode('/', $args) . '/';
+    }
+
+    return [
+        'itemid' => 0,
+        'filepath' => $filepath,
+    ];
+}
