@@ -96,7 +96,7 @@ class core_webservice_renderer extends plugin_renderer_base {
     }
 
     /**
-     * Display list of authorised users
+     * Display list of authorised users for the given external service.
      *
      * @param array $users authorised users
      * @param int $serviceid service id
@@ -104,25 +104,43 @@ class core_webservice_renderer extends plugin_renderer_base {
      */
     public function admin_authorised_user_list($users, $serviceid) {
         global $CFG;
-        $html = $this->output->box_start('generalbox', 'alloweduserlist');
+
+        $listitems = [];
+        $extrafields = \core_user\fields::get_identity_fields(context_system::instance());
+
         foreach ($users as $user) {
-            $modifiedauthoriseduserurl = new moodle_url('/' . $CFG->admin . '/webservice/service_user_settings.php',
-                            array('userid' => $user->id, 'serviceid' => $serviceid));
-            $html .= html_writer::tag('a', $user->firstname . " "
-                            . $user->lastname . ", " . $user->email,
-                            array('href' => $modifiedauthoriseduserurl));
-            //add missing capabilities
-            if (!empty($user->missingcapabilities)) {
-                $html .= html_writer::tag('div',
-                                get_string('usermissingcaps', 'webservice', $user->missingcapabilities)
-                                . '&nbsp;' . $this->output->help_icon('missingcaps', 'webservice'),
-                                array('class' => 'missingcaps', 'id' => 'usermissingcaps'));
-                $html .= html_writer::empty_tag('br');
-            } else {
-                $html .= html_writer::empty_tag('br') . html_writer::empty_tag('br');
+            $settingsurl = new moodle_url('/admin/webservice/service_user_settings.php',
+                ['userid' => $user->id, 'serviceid' => $serviceid]);
+
+            $identity = [];
+            foreach ($extrafields as $extrafield) {
+                if (isset($user->{$extrafield})) {
+                    $identity[] = s($user->{$extrafield});
+                }
             }
+            $identity = $identity ? html_writer::div(implode(', ', $identity), 'small') : '';
+
+            $link = html_writer::link($settingsurl, fullname($user));
+
+            if (!empty($user->missingcapabilities)) {
+                $count = html_writer::span(count($user->missingcapabilities), 'badge badge-danger');
+                $links = array_map(function($capname) {
+                    return get_capability_docs_link((object)['name' => $capname]) . html_writer::div($capname, 'text-muted');
+                }, $user->missingcapabilities);
+                $list = html_writer::alist($links);
+                $help = $this->output->help_icon('missingcaps', 'webservice');
+                $missingcaps = print_collapsible_region(html_writer::div($list . $help, 'missingcaps'), 'small',
+                    html_writer::random_id('usermissingcaps'), get_string('usermissingcaps', 'webservice', $count), '', true, true);
+
+            } else {
+                $missingcaps = '';
+            }
+
+            $listitems[] = $link . $identity . $missingcaps;
         }
-        $html .= $this->output->box_end();
+
+        $html = html_writer::div(html_writer::alist($listitems), 'alloweduserlist');
+
         return $html;
     }
 
@@ -166,29 +184,6 @@ class core_webservice_renderer extends plugin_renderer_base {
                 $formcontinue, $formcancel);
     }
 
-    /**
-     * Display a confirmation page to delete a token
-     *
-     * @param stdClass $token Required properties: id (token id), firstname (user firstname), lastname (user lastname), name (service name)
-     * @return string html
-     */
-    public function admin_delete_token_confirmation($token) {
-        global $CFG;
-        $optionsyes = array('tokenid' => $token->id, 'action' => 'delete',
-            'confirm' => 1, 'sesskey' => sesskey());
-        $optionsno = array('section' => 'webservicetokens', 'sesskey' => sesskey());
-        $formcontinue = new single_button(
-                        new moodle_url('/' . $CFG->admin . '/webservice/tokens.php', $optionsyes),
-                        get_string('delete'));
-        $formcancel = new single_button(
-                        new moodle_url('/' . $CFG->admin . '/settings.php', $optionsno),
-                        get_string('cancel'), 'get');
-        return $this->output->confirm(get_string('deletetokenconfirm', 'webservice',
-                        (object) array('user' => $token->firstname . " "
-                            . $token->lastname, 'service' => $token->name)),
-                $formcontinue, $formcancel);
-    }
-
     /**
      * Display a list of functions for a given service
      * If the service is built-in, do not display remove/add operation (read-only)
@@ -214,8 +209,13 @@ class core_webservice_renderer extends plugin_renderer_base {
                 $table->align[] = 'center';
             }
 
+            $anydeprecated = false;
             foreach ($functions as $function) {
-                $function = external_function_info($function);
+                $function = external_api::external_function_info($function);
+
+                if (!empty($function->deprecated)) {
+                    $anydeprecated = true;
+                }
                 $requiredcaps = html_writer::tag('div',
                                 empty($function->capabilities) ? '' : $function->capabilities,
                                 array('class' => 'functiondesc'));
@@ -244,6 +244,10 @@ class core_webservice_renderer extends plugin_renderer_base {
 
         //display add function operation (except for build-in service)
         if (empty($service->component)) {
+
+            if (!empty($anydeprecated)) {
+                debugging('This service uses deprecated functions, replace them by the proposed ones and update your client/s.', DEBUG_DEVELOPER);
+            }
             $addurl = new moodle_url('/' . $CFG->admin . '/webservice/service_functions.php',
                             array('sesskey' => sesskey(), 'id' => $service->id, 'action' => 'add'));
             $html .= html_writer::tag('a', get_string('addfunctions', 'webservice'), array('href' => $addurl));
@@ -332,7 +336,7 @@ class core_webservice_renderer extends plugin_renderer_base {
 
                 $validuntil = '';
                 if (!empty($token->validuntil)) {
-                    $validuntil = date("F j, Y"); //TODO MDL-31193 language support (look for moodle function)
+                    $validuntil = userdate($token->validuntil, get_string('strftimedatetime', 'langconfig'));
                 }
 
                 $tokenname = $token->name;
@@ -364,7 +368,7 @@ class core_webservice_renderer extends plugin_renderer_base {
      * ws description object can be 'external_multiple_structure', 'external_single_structure'
      * or 'external_value'
      *
-     * Example of documentation for moodle_group_create_groups function:
+     * Example of documentation for core_group_create_groups function:
      * list of (
      *     object {
      *         courseid int //id of course
@@ -401,7 +405,7 @@ class core_webservice_renderer extends plugin_renderer_base {
             $paramdesc .= html_writer::start_tag('i', array());
             $paramdesc .= "//";
 
-            $paramdesc .= $params->desc;
+            $paramdesc .= s($params->desc);
 
             $paramdesc .= html_writer::end_tag('i');
 
@@ -643,10 +647,6 @@ EOF;
         $docurl = new moodle_url('http://docs.moodle.org/dev/Creating_a_web_service_client');
         $docinfo->doclink = html_writer::tag('a',
                         get_string('wsclientdoc', 'webservice'), array('href' => $docurl));
-        $documentationhtml .= html_writer::start_tag('table',
-                        array('style' => "margin-left:auto; margin-right:auto;"));
-        $documentationhtml .= html_writer::start_tag('tr', array());
-        $documentationhtml .= html_writer::start_tag('td', array());
         $documentationhtml .= get_string('wsdocumentationintro', 'webservice', $docinfo);
         $documentationhtml .= $br . $br;
 
@@ -680,7 +680,7 @@ EOF;
             $documentationhtml .= html_writer::start_tag('div',
                             array('style' => 'border:solid 1px #DEDEDE;background:#E2E0E0;
                         color:#222222;padding:4px;'));
-            $documentationhtml .= $description->description;
+            $documentationhtml .= s($description->description);
             $documentationhtml .= html_writer::end_tag('div');
             $documentationhtml .= $br . $br;
 
@@ -714,7 +714,7 @@ EOF;
                 $documentationhtml .= " (" . $required . ")"; // argument is required or optional ?
                 $documentationhtml .= $br;
                 $documentationhtml .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
-                        . $paramdesc->desc; // argument description
+                        . s($paramdesc->desc); // Argument description.
                 $documentationhtml .= $br . $br;
                 // general structure of the argument
                 $documentationhtml .= $this->colored_box_with_pre_tag(
@@ -806,16 +806,26 @@ EOF;
                 $documentationhtml .= html_writer::end_tag('span');
             }
             $documentationhtml .= $br . $br;
+
+            // Login required info.
+            $documentationhtml .= html_writer::start_tag('span', array('style' => 'color:#EA33A6'));
+            $documentationhtml .= get_string('loginrequired', 'webservice') . $br;
+            $documentationhtml .= html_writer::end_tag('span');
+            $documentationhtml .= $description->loginrequired ? get_string('yes') : get_string('no');
+            $documentationhtml .= $br . $br;
+
+            // Ajax info.
+            $documentationhtml .= html_writer::start_tag('span', array('style' => 'color:#EA33A6'));
+            $documentationhtml .= get_string('callablefromajax', 'webservice') . $br;
+            $documentationhtml .= html_writer::end_tag('span');
+            $documentationhtml .= $description->allowed_from_ajax ? get_string('yes') : get_string('no');
+            $documentationhtml .= $br . $br;
+
             if (empty($printableformat)) {
                 $documentationhtml .= print_collapsible_region_end(true);
             }
         }
 
-        // close the table and return the documentation
-        $documentationhtml .= html_writer::end_tag('td');
-        $documentationhtml .= html_writer::end_tag('tr');
-        $documentationhtml .= html_writer::end_tag('table');
-
         return $documentationhtml;
     }
 
